Ongoing Work
============

ES
--

* Guided evolutionary strategies: Augmenting random search with surrogate gradients
* Structured evolution with compact architectures for scalable policy optimization
* A comparison of global search algorithms for continuous black box optimization

CEM
---

* Application of the cross-entropy method to clustering and vector quantization
* Global likelihood optimization via the cross-entropy method, with an application to mixture models
* On the convergence of the cross-entropy method
* The cross-entropy method for fast policy search
* Entropy optimization principles with applications

PSO
---

* PSO-X: A component-based framework for the automatic design of particle swarm optimization algorithms
* Incremental social learning in particle swarms
* Frankenstein’s PSO: A composite particle swarm optimization algorithm
* The fully informed particle swarm: Simpler, maybe better
* The particle swarm - explosion, stability, and convergence in a multidimensional complex space

SA
--

* Simulated annealing for constrained global optimization
* Simulated annealing and Boltzmann machines

RS
--

* Learning to guide random search
* Online convex optimization in the bandit setting: Gradient descent without a gradient

BBO
---

* Dynamic pricing with online learning and strategic consumers: An application of the aggregation algorithm
* Finding optimal algorithmic parameters using derivative-free optimization
* The NEWUOA software for unconstrained optimization without derivatives
* A pattern search filter method for nonlinear programming without derivatives
* Hydrodynamic design using a derivativefree method
* Aerodynamic noise control by optimal shape design
* Pattern search methods for user-provided points: Application to molecular geometry problems
* A framework for managing models in nonlinear optimization of computationally expensive functions
* Optimization by direct search in matrix computations
